@@ -32,15 +32,21 @@ class BinaryHammingDistance(BinaryStatScores):
     and :math:`\bullet_{il}` refers to the :math:`l`-th label of the :math:`i`-th sample of that
     tensor.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (int or float tensor): ``(N, ...)``. If preds is a floating point tensor with values outside
-      [0,1] range we consider the input to be logits and will auto apply sigmoid per element. Addtionally,
-      we convert to int tensor with thresholding using the value in ``threshold``.
-    - ``target`` (int tensor): ``(N, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int or float tensor of shape ``(N, ...)``. If preds is a floating point
+      tensor with values outside [0,1] range we consider the input to be logits and will auto apply sigmoid per
+      element. Addtionally, we convert to int tensor with thresholding using the value in ``threshold``.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``bhd`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``, the metric returns a scalar value.
+        - If ``multidim_average`` is set to ``samplewise``, the metric returns ``(N,)`` vector consisting of a
+          scalar value per sample.
 
     Args:
         threshold: Threshold for transforming probability to binary {0,1} predictions
@@ -56,10 +62,6 @@ class BinaryHammingDistance(BinaryStatScores):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        If ``multidim_average`` is set to ``global``, the metric returns a scalar value. If ``multidim_average``
-        is set to ``samplewise``, the metric returns ``(N,)`` vector consisting of a scalar value per sample.
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import BinaryHammingDistance
         >>> target = torch.tensor([0, 1, 0, 1, 0, 1])
@@ -109,15 +111,28 @@ class MulticlassHammingDistance(MulticlassStatScores):
     and :math:`\bullet_{il}` refers to the :math:`l`-th label of the :math:`i`-th sample of that
     tensor.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds``: ``(N, ...)`` (int tensor) or ``(N, C, ..)`` (float tensor). If preds is a floating point
-      we apply ``torch.argmax`` along the ``C`` dimension to automatically convert probabilities/logits into
-      an int tensor.
-    - ``target`` (int tensor): ``(N, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)`` or float tensor of shape ``(N, C, ..)``.
+      If preds is a floating point we apply ``torch.argmax`` along the ``C`` dimension to automatically convert
+      probabilities/logits into an int tensor.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mchd`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``average`` and
+      ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
+          - If ``average=None/'none'``, the shape will be ``(C,)``
+
+        - If ``multidim_average`` is set to ``samplewise``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
+          - If ``average=None/'none'``, the shape will be ``(N, C)``
 
     Args:
         num_classes: Integer specifing the number of classes
@@ -143,19 +158,6 @@ class MulticlassHammingDistance(MulticlassStatScores):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        The returned shape depends on the ``average`` and ``multidim_average`` arguments:
-
-        - If ``multidim_average`` is set to ``global``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
-          - If ``average=None/'none'``, the shape will be ``(C,)``
-
-        - If ``multidim_average`` is set to ``samplewise``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
-          - If ``average=None/'none'``, the shape will be ``(N, C)``
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import MulticlassHammingDistance
         >>> target = torch.tensor([2, 1, 0, 0])
@@ -163,8 +165,8 @@ class MulticlassHammingDistance(MulticlassStatScores):
         >>> metric = MulticlassHammingDistance(num_classes=3)
         >>> metric(preds, target)
         tensor(0.1667)
-        >>> metric = MulticlassHammingDistance(num_classes=3, average=None)
-        >>> metric(preds, target)
+        >>> mchd = MulticlassHammingDistance(num_classes=3, average=None)
+        >>> mchd(preds, target)
         tensor([0.5000, 0.0000, 0.0000])
 
     Example (preds is float tensor):
@@ -179,8 +181,8 @@ class MulticlassHammingDistance(MulticlassStatScores):
         >>> metric = MulticlassHammingDistance(num_classes=3)
         >>> metric(preds, target)
         tensor(0.1667)
-        >>> metric = MulticlassHammingDistance(num_classes=3, average=None)
-        >>> metric(preds, target)
+        >>> mchd = MulticlassHammingDistance(num_classes=3, average=None)
+        >>> mchd(preds, target)
         tensor([0.5000, 0.0000, 0.0000])
 
     Example (multidim tensors):
@@ -190,8 +192,8 @@ class MulticlassHammingDistance(MulticlassStatScores):
         >>> metric = MulticlassHammingDistance(num_classes=3, multidim_average='samplewise')
         >>> metric(preds, target)
         tensor([0.5000, 0.7222])
-        >>> metric = MulticlassHammingDistance(num_classes=3, multidim_average='samplewise', average=None)
-        >>> metric(preds, target)
+        >>> mchd = MulticlassHammingDistance(num_classes=3, multidim_average='samplewise', average=None)
+        >>> mchd(preds, target)
         tensor([[0.0000, 1.0000, 0.5000],
                 [1.0000, 0.6667, 0.5000]])
     """
@@ -215,15 +217,29 @@ class MultilabelHammingDistance(MultilabelStatScores):
     and :math:`\bullet_{il}` refers to the :math:`l`-th label of the :math:`i`-th sample of that
     tensor.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (int or float tensor): ``(N, C, ...)``. If preds is a floating point tensor with values outside
-      [0,1] range we consider the input to be logits and will auto apply sigmoid per element. Addtionally,
-      we convert to int tensor with thresholding using the value in ``threshold``.
-    - ``target`` (int tensor): ``(N, C, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int tensor or float tensor of shape ``(N, C, ...)``. If preds is a
+      floating point tensor with values outside [0,1] range we consider the input to be logits and will auto
+      apply sigmoid per element. Addtionally, we convert to int tensor with thresholding using the value in
+      ``threshold``.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, C, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mlhd`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``average`` and
+      ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
+          - If ``average=None/'none'``, the shape will be ``(C,)``
+
+        - If ``multidim_average`` is set to ``samplewise``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
+          - If ``average=None/'none'``, the shape will be ``(N, C)``
 
     Args:
         num_labels: Integer specifing the number of labels
@@ -248,19 +264,6 @@ class MultilabelHammingDistance(MultilabelStatScores):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        The returned shape depends on the ``average`` and ``multidim_average`` arguments:
-
-        - If ``multidim_average`` is set to ``global``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
-          - If ``average=None/'none'``, the shape will be ``(C,)``
-
-        - If ``multidim_average`` is set to ``samplewise``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
-          - If ``average=None/'none'``, the shape will be ``(N, C)``
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import MultilabelHammingDistance
         >>> target = torch.tensor([[0, 1, 0], [1, 0, 1]])
@@ -268,8 +271,8 @@ class MultilabelHammingDistance(MultilabelStatScores):
         >>> metric = MultilabelHammingDistance(num_labels=3)
         >>> metric(preds, target)
         tensor(0.3333)
-        >>> metric = MultilabelHammingDistance(num_labels=3, average=None)
-        >>> metric(preds, target)
+        >>> mlhd = MultilabelHammingDistance(num_labels=3, average=None)
+        >>> mlhd(preds, target)
         tensor([0.0000, 0.5000, 0.5000])
 
     Example (preds is float tensor):
@@ -279,8 +282,8 @@ class MultilabelHammingDistance(MultilabelStatScores):
         >>> metric = MultilabelHammingDistance(num_labels=3)
         >>> metric(preds, target)
         tensor(0.3333)
-        >>> metric = MultilabelHammingDistance(num_labels=3, average=None)
-        >>> metric(preds, target)
+        >>> mlhd = MultilabelHammingDistance(num_labels=3, average=None)
+        >>> mlhd(preds, target)
         tensor([0.0000, 0.5000, 0.5000])
 
     Example (multidim tensors):
@@ -295,8 +298,8 @@ class MultilabelHammingDistance(MultilabelStatScores):
         >>> metric = MultilabelHammingDistance(num_labels=3, multidim_average='samplewise')
         >>> metric(preds, target)
         tensor([0.6667, 0.8333])
-        >>> metric = MultilabelHammingDistance(num_labels=3, multidim_average='samplewise', average=None)
-        >>> metric(preds, target)
+        >>> mlhd = MultilabelHammingDistance(num_labels=3, multidim_average='samplewise', average=None)
+        >>> mlhd(preds, target)
         tensor([[0.5000, 0.5000, 1.0000],
                 [1.0000, 1.0000, 0.5000]])
     """
