@@ -31,10 +31,14 @@ class CosineSimilarity(Metric):
 
     where :math:`y` is a tensor of target values, and :math:`x` is a tensor of predictions.
 
-    Forward accepts
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N,d)``
-    - ``target`` (float tensor): ``(N,d)``
+    - ``preds`` (:class:`~torch.Tensor`): Predicted float tensor with shape ``(N,d)``
+    - ``target`` (:class:`~torch.Tensor`): Ground truth float tensor with shape ``(N,d)``
+
+    As output of ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``cosine_similarity`` (:class:`~torch.Tensor`): A float tensor with the cosine similarity
 
     Args:
         reduction: how to reduce over the batch dimension using 'sum', 'mean' or 'none' (taking the individual scores)
@@ -69,12 +73,7 @@ class CosineSimilarity(Metric):
         self.add_state("target", [], dist_reduce_fx="cat")
 
     def update(self, preds: Tensor, target: Tensor) -> None:
-        """Update metric states with predictions and targets.
-
-        Args:
-            preds: Predicted tensor with shape ``(N,d)``
-            target: Ground truth tensor with shape ``(N,d)``
-        """
+        """Update metric states with predictions and targets."""
         preds, target = _cosine_similarity_update(preds, target)
 
         self.preds.append(preds)
